/*
* Copyright (C) 2012 The Android Open Source Project
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package com.motorolamobility.studio.android.db.devices;

import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

import com.motorola.studio.android.common.log.StudioLogger;
import com.motorolamobility.studio.android.db.core.DbCoreActivator;
import com.motorolamobility.studio.android.db.devices.ui.preferences.DbPreferencePage;

/**
 * The activator class controls the plug-in life cycle
 */
public class DbDevicesPlugin extends AbstractUIPlugin
{

    // The plug-in ID
    public static final String PLUGIN_ID = "com.motorolamobility.studio.android.db.devices"; //$NON-NLS-1$

    public static final String DB_TEMP_PATH_PREFERENCE = PLUGIN_ID + ".dbstudiotemppath"; //$NON-NLS-1$

    // The shared instance
    private static DbDevicesPlugin plugin;

    /*
     * (non-Javadoc)
     * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
     */
    @Override
    public void start(BundleContext context) throws Exception
    {
        StudioLogger.debug(DbCoreActivator.class,
                "Starting MOTODEV Studio for Android Database Devices Support Plugin...");

        super.start(context);
        DbPreferencePage.restoreBackWardPref(this.getPreferenceStore());
        plugin = this;

        StudioLogger.debug(DbCoreActivator.class,
                "MOTODEV Studio for Android Database Devices Support Plugin started...");
    }

    /*
     * (non-Javadoc)
     * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
     */
    @Override
    public void stop(BundleContext context) throws Exception
    {
        plugin = null;
        super.stop(context);
    }

    /**
     * Returns the shared instance
     *
     * @return the shared instance
     */
    public static DbDevicesPlugin getDefault()
    {
        return plugin;
    }

}
